emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] Changes to emacs/src/nsfont.m,v


From: Adrian Robert
Subject: [Emacs-diffs] Changes to emacs/src/nsfont.m,v
Date: Tue, 22 Jul 2008 12:33:14 +0000

CVSROOT:        /sources/emacs
Module name:    emacs
Changes by:     Adrian Robert <arobert> 08/07/22 12:33:13

Index: nsfont.m
===================================================================
RCS file: /sources/emacs/emacs/src/nsfont.m,v
retrieving revision 1.8
retrieving revision 1.9
diff -u -b -r1.8 -r1.9
--- nsfont.m    19 Jul 2008 22:23:30 -0000      1.8
+++ nsfont.m    22 Jul 2008 12:33:13 -0000      1.9
@@ -96,7 +96,7 @@
       char *tmp = strdup (SDATA (SYMBOL_NAME (tem)));
       NSString *family;
       nsfont_unescape_name (tmp);
-      /* PENDING: this seems to be needed only for font names that are
+      /* TODO: this seems to be needed only for font names that are
          hard-coded into emacs, like 'helvetica' for splash screen */
       if (tmp)
         tmp[0] = toupper (tmp[0]);
@@ -108,7 +108,7 @@
 
 
 /* Converts FONT_WEIGHT, FONT_SLANT, FONT_WIDTH to NSFont traits. */
-/* PENDING (20080601): The font backend's strategy for handling font
+/* TODO (20080601): The font backend's strategy for handling font
            styles continues to evolve.  When/if this stabilizes, we
            can change the code here to be more sophisticated and accurate.
            For now, we rely on "normal/plain" style being numeric 100. */
@@ -413,7 +413,7 @@
     if (fontNames && [fontNames count]  > 0)
       {
         NSString *fontName = [fontNames objectAtIndex: 0];
-        /*PENDING: is there a more efficient way to get family name? */
+        /* XXX: is there a more efficient way to get family name? */
         NSFont *font = [NSFont fontWithName: fontName size: 0];
         if (font != nil)
           {
@@ -453,7 +453,7 @@
   NSString *family;
   while (family = [families nextObject])
       list = Fcons (intern ([family UTF8String]), list);
   /*PENDING: escape the name? */
 
   if (NSFONT_TRACE)
     fprintf (stderr, "nsfont: list families returning %d entries\n",
@@ -519,7 +519,7 @@
   font_info = (struct nsfont_info *) XFONT_OBJECT (font_object);
   font = (struct font *)font_info;
   if (!font)
-    return Qnil; /*PENDING: this copies w32, but causes a segfault */
+    return Qnil; /* FIXME: this copies w32, but causes a segfault */
 
   if (NSFONT_TRACE)
     {
@@ -627,7 +627,7 @@
   font->relative_compose = 0;
   font->font_encoder = NULL;
 
-  /*PENDING: does anything care about this? */
+  /* TODO: does anything care about this? */
   font->props[FONT_FORMAT_INDEX] = Qns;
   font->props[FONT_FILE_INDEX] = Qnil;
 
@@ -723,7 +723,7 @@
     /* set up metrics portion of font struct */
     font->ascent = [sfont ascender];
     font->descent = -[sfont descender];
-    font->min_width = [sfont widthOfString: @"|"]; /* PENDING */
+    font->min_width = [sfont widthOfString: @"|"]; /* FIXME */
     font->space_width = lrint (nsfont_char_width (sfont, ' '));
     font->average_width = lrint (font_info->width);
     font->max_width = lrint (font_info->max_bounds.width);
@@ -748,7 +748,7 @@
   struct nsfont_info *font_info = (struct nsfont_info *)font;
   int i;
 
   /* PENDING: this occurs apparently due to same failure to detect same font
      that causes need for cache in nsfont_open ()
      (came after unicode-2 -> trunk) */
   if (!font_info)
@@ -820,7 +820,7 @@
   for (i =0; i<nglyphs; i++)
     {
       /* get metrics for this glyph, filling cache if need be */
-      /* PENDING: get metrics for whole string from an NSLayoutManager
+      /* TODO: get metrics for whole string from an NSLayoutManager
                  (if not too slow) */
       high = (code[i] & 0xFF00) >> 8;
       low = code[i] & 0x00FF;
@@ -903,7 +903,7 @@
     int cwidth, twidth = 0;
     int hi, lo;
     char isComposite = 0; /* s->first_glyph->type == COMPOSITE_GLYPH; */
     /* PENDING: composition: no vertical displacement is considered. */
     t+= s->gidx; /* advance into composition */
     for (i =0; i<s->nchars - s->gidx; i++, t++)
       {
@@ -915,7 +915,7 @@
           }
         else
           {
-            if (!font->metrics[hi]) /*PENDING: why/how can we need this now? */
+            if (!font->metrics[hi]) /* FIXME: why/how can we need this now? */
               ns_glyph_metrics (font, hi);
             cwidth = font->metrics[hi][lo].width;
           }
@@ -987,7 +987,7 @@
   col = (NS_FACE_FOREGROUND (face) != nil
          ? ns_lookup_indexed_color (NS_FACE_FOREGROUND (face), s->f)
          : FRAME_FOREGROUND_COLOR (s->f));
   /*PENDING: find another way to pass this */
   bgCol = (ns_tmp_flags != NS_DUMPGLYPH_FOREGROUND ? nil
            : (NS_FACE_BACKGROUND (face) != 0
               ? ns_lookup_indexed_color (NS_FACE_BACKGROUND (face), s->f)
@@ -1320,7 +1320,7 @@
         g = unichars[i];
 #else
         g = glyphStorage->cglyphs[i];
-        /*PENDING: is this a good check?  maybe need to use coveredChars.. */
+        /* TODO: is this a good check?  maybe need to use coveredChars.. */
         if (g > numGlyphs)
           g = 0xFFFF; /* hopefully unused... */
 #endif
@@ -453,7 +453,7 @@
   while (family = [families nextObject])
       list = Fcons (intern ([family UTF8String]), list);
-  /*PENDING: escape the name? */
+  /* FIXME: escape the name? */
 
   if (NSFONT_TRACE)
@@ -748,7 +748,7 @@
   int i;
 
-  /* PENDING: this occurs apparently due to same failure to detect same font
+  /* FIXME: this occurs apparently due to same failure to detect same font
      that causes need for cache in nsfont_open ()
      (came after unicode-2 -> trunk) */
@@ -903,7 +903,7 @@
     int hi, lo;
     char isComposite = 0; /* s->first_glyph->type == COMPOSITE_GLYPH; */
-    /* PENDING: composition: no vertical displacement is considered. */
+    /* FIXME: composition: no vertical displacement is considered. */
     t+= s->gidx; /* advance into composition */
     for (i =0; i<s->nchars - s->gidx; i++, t++)
@@ -987,7 +987,7 @@
          ? ns_lookup_indexed_color (NS_FACE_FOREGROUND (face), s->f)
          : FRAME_FOREGROUND_COLOR (s->f));
-  /*PENDING: find another way to pass this */
+  /* FIXME: find another way to pass this */
   bgCol = (ns_tmp_flags != NS_DUMPGLYPH_FOREGROUND ? nil
            : (NS_FACE_BACKGROUND (face) != 0




reply via email to

[Prev in Thread] Current Thread [Next in Thread]